# atqo

[![Documentation Status](https://readthedocs.org/projects/atqo/badge/?version=latest)](https://atqo.readthedocs.io/en/latest)
[![codeclimate](https://img.shields.io/codeclimate/maintainability/endremborza/atqo.svg)](https://codeclimate.com/github/endremborza/atqo)
[![codecov](https://img.shields.io/codecov/c/github/endremborza/atqo)](https://codecov.io/gh/endremborza/atqo)
[![pypi](https://img.shields.io/pypi/v/atqo.svg)](https://pypi.org/project/atqo/)

Async Task Queue Orchestrator 

(task) properties can have arbitrary limits
(actor) capabilities must have linear limits - based on (global) resources

with 
- complex resource manager
- flexible abstractions for schedulers, actors, resources and resource limits

came from [aswan](https://github.com/endremborza/aswan), as part of [sscub](https://sscu-budapest.github.io/) ecosystem cleanup

lots to do, but aswan got bloated
